clear all
set more off, permanently
set varabbrev off , permanently
set matsize 8000
set scheme s1color, permanently
graph set window fontface "Liberation Serif"


/*** Directory structure 
Replace with appropriate directory structure.
**/
global CCPPANEL "/PanelData/"
global ROOTDIR "/Credit_cards/Revolver"
local INDIR "$ROOTDIR/Intermediate/"
local PROGDIR "$ROOTDIR/Programs/"
global OUTDIR "$ROOTDIR/Intermediate/"
global MEMDIR "MakingEndsMeet/Data"

capture log close
cd "`PROGDIR'"
log using CC_EM_4.txt_10-7-2021, replace text

/*************
Project: Credit Card Use Create EM
Programmer: Scott Fulford
Date: 9/12/2015 On Fed/Equifax
12/16/2019 on CFPB CCP


*************/


//Whether to load and prep data or use saved prepped data
//yes or no
local prepdata no 

/*** Transition start parameters 
SCPC yearly 82.7 percent of self-reported revolvers in one year are also revolvers in the next year. 
87.5 percent of convenience users convenience next year
Quarterly transitions
****/
global init_pRR = .827^(.25)
global init_pCC = .875^(.25)


if "`prepdata'"=="yes" {
/***Load MEM and CCP for MEM sample, process so looks like CCP panel */
use "$MEMDIR/Wave1/MakingEndsMeetWave1_final", clear
svyset [pw=weight]

keep if disposition <.
gen date = monthly("jun2019", "MY")
tempfile mem
save `mem', replace

use "$MEMDIR/MEM_CCPvariables", clear


//Reshape with a generic list
//put all the needed variables in a local macro
//Assumes it is a panel so any quarterly date should work
unab mylist: *_jun2019

*cut out the "_june2019" at the end to obtain the actual stubs
foreach v of local mylist {
	local stubs `"`stubs' `=substr("`v'",1,length("`v'")-8)'"' 
} 
disp "`stubs'"
*reshape (assuming you have a unique identifier "id")
reshape long `stubs', i(consumer_nb) j(date_stub) string
replace date_stub = substr(date_stub, 2, .)
gen date = monthly(date_stub, "MY")

merge 1:1 consumer_nb date using `mem'
drop date_stub _merge
gen inMEM=1

//Fill back when observe birth year, note that fills in again for panel
//Note: birth year not included before 2009. We do observe consumers who are only
//there before 2009. So using age necessarily drops these consumers.
replace birthyear = . if birthyear >=.
by consumer_nb: egen birthyear_filled = mean(birthyear)
gen year = year(dofm(date))
capture drop age
gen age = year - birthyear_filled
drop year

svyset [pw=weight]

save `mem', replace



use "$CCPPANEL/CCPsample_panel.dta"

gen inMEM =0
merge 1:1 consumer_nb date using `mem', update 

gen year = year(dofm(date))

//Drop before pandemic
keep if date>ym(2004,12) & date <=ym(2019,12)

sort consumer_nb date

//Reduce sample size
//keep if mod(consumer_nb,8)==0

gen ccdebt1 = (ccdebt>0 & ccdebt <.) if ccdebt <.
gen cclimit1 = (cclimit>0 ) if cclimit<.

//Exclude consumer quarters without open credit card, so when transforming
//don't include no cc quarters
replace ccdebt =. if openCC ==0 | openCC >=.
replace cclimit =. if openCC ==0 | openCC >=.

//Create variable that includes the 0s by shifting out by 10
gen ln_cclimit100 =log(cclimit+100)  
gen ln_ccdebt100 = log(ccdebt+100) 
gen ln_cclimit = log(cclimit)
gen ln_ccdebt = log(ccdebt)
// state already created gen state = floor(tract/10^9)
gen a1 = ((age-50)/50)
gen a2 = a1^2
gen a3 = a1^3

/*Form ccuse variable that is topped out at 3, over 3 it is missing and so
will not be used
*/
gen ccuse = ccdebt/cclimit if openCC >0 & openCC <.
replace ccuse = . if ccuse >3
gen ccuse2 = ccuse^2
gen ccuse3 = ccuse^3


//keep id date age ln_ccdebt ln_cclimit year ccdebt ccdebt1 cclimit1 cclimit_upd ccuse
keep if age >=20 & age <=80
//Create variables

gen Dccdebt1 = S.ccdebt1

gen La1 = L.a1
gen Dab = a1*ln_cclimit-La1*L.ln_cclimit
gen Da2b = a1^2*ln_cclimit-La1^2*L.ln_cclimit

gen ccuse_t = L.ccdebt/cclimit
replace ccuse_t = 0 if L.ccdebt <=0
gen ccuse_t0 = 1 if ccuse_t ==0
replace ccuse_t0 =0 if ccuse_t >0 &ccuse_t <.
gen ccuse_t1 = 1 if ccuse_t >=1.1 & ccuse_t <.
replace ccuse_t1 =0 if ccuse_t < 1.1 & ccuse_t <.
replace ccuse_t = 1.1 if ccuse_t >=1.1 & ccuse_t<.
gen ccut = L.ccuse_t
forvalues xx = 2(1)5 {
	capture drop age`xx'
	capture drop ccut`xx'
	gen age`xx' = age^`xx'
	gen ccut`xx' = ccut^`xx'
}
gen ccut0 = L.ccuse_t0
gen ccut1 = L.ccuse_t1

//Find f(age) = average(B/D)

reg ccuse a1 a2 a3 if ccuse <=2
gen fage = 1/(_b[_cons]+_b[a1]*a1+_b[a2]*a2+_b[a3]*a3)
gen fageb = fage*ln_cclimit

gen Dfageb = D.fageb
	
gen Dln_ccdebt = D.ln_ccdebt

reg Dln_ccdebt  i.year
predict Dln_ccdebtY, resid
gen LDln_ccdebtY = L.Dln_ccdebtY
/*
gen qy = (year-1999)*4 + quarter-1
sum qy
//Create time effects with the trend removed
forvalues qq = `r(min)'(1)`r(max)' {
	quietly gen dqy`qq'= (qy==`qq')
}
forvalues  qq = `r(min)'(1)`r(max)' {
	quietly gen ddqy`qq' = dqy`qq' -((qy-1)*dqy0 - (qy-2)*dqy1) 
}		

*/
/*For each variable in model, remove mean and year effects*/
foreach var in ln_ccdebt ln_cclimit ln_ccdebt100 ln_cclimit100 ccdebt cclimit fageb a1 a2 a3 ccuse {
	capture drop B`var'
	quietly xtreg `var' i.date, fe
	quietly predict B`var', e
}


 
gen logitConvSCF = .10847 + 2.0822*a1 + .02878*a2 + -1.0494*a3   
gen pConvageSCF = exp(logitConvSCF)/(1+exp(logitConvSCF))
local logitConvuseSCF  1.603 + -8.7325*ccuse + 8.6856*ccuse^2 -3.735*ccuse^3   
gen pConvuseSCF = exp(`logitConvuseSCF')/(1+exp(`logitConvuseSCF'))

local logitConvuseageSCF  1.535 + -7.812*ccuse + 6.253*ccuse^2 -1.799*ccuse^3 + 2.574*a1 - .170*a2 + -2.927*a3  
gen pConvSCF = exp(`logitConvuseSCF')/(1+exp(`logitConvuseSCF'))

gen convMEM = 0 if q39 ==1
replace convMEM = 1 if q39 ==0
gen revMEM = 1-convMEM
capture drop label revolver
label def revolver 0 "Not MEM revolver" 1 "MEM revolver"
label values revMEM revolver

logit convMEM a1 a2 a3
predict pConvageMEM, pr
matrix blCMEMage = e(b)

logit convMEM ccuse ccuse2 ccuse3
predict pConvuseMEM, pr
matrix blCMEMuse = e(b)

logit convMEM ccuse ccuse2 ccuse3 a1 a2 a3
predict pConvMEM, pr
matrix blCMEMuseage = e(b)
gen pRevMEM = 1-pConvMEM 



save  "$OUTDIR/MEM_CCP_ccard_prepped.dta", replace

} //end data prep

/****** Define stata and mata programs *****/

//Create a new id varaible stored in id_2 that is does not have any panel gaps
//id is now the combination of id and id_2
//Assumes date is evenly spaced
//datediff is the standard difference between dates, 3 months for the data setup
capture program drop nogap_id
program def nogap_id
version 16.1
args  id date id2 ndatediff
	tempvar datediff gap sgap
	sort `id' `date'
	by `id': gen `datediff' = `date' - `date'[_n-1]
	
	gen `gap' = 0
	replace `gap' =1 if `datediff' > `ndatediff' & `datediff' <.
	by `id': gen `sgap' = sum(`gap')
	gen long `id2' = `id'*100 + `sgap'
end
//nogap_id consumer_nb date id2 3


//Calculate M particles of initial state R (revolving ==1) for each id based only on 
// variable pR0, assuming ccdebt =0 ->R=0
capture program drop initial_states
program def initial_states
version 16.1
args  id date pR0 M
	//Initialize states 
	forvalues m=1/`M' {
		//Define a wide multiple imputation
		capture drop R_`m'
		gen byte R_`m' =.
		sort `id' `date'
		capture drop rvar
		tempvar rvar
		gen `rvar' = runiform()
		//Set initial value drawing from initial probability 
		
		replace R_`m'= 1 if `rvar'<=`pR0' 
		replace R_`m'= 0 if ccdebt ==0
		replace R_`m' = 0 if `rvar'>`pR0' & !missing(`rvar')
	}
end

//initial_states consumer_nb date pRevMEM 5
	
//Calculate M particles of based on current etimates storing R_m (revolving ==1) for each id  
// assuming ccdebt =0 ->R=0
// Uses densities stored in varibles fidR and fidC
// Writes over R_m's
// Assumes not gaps in id date (run nogap_id to ensure) so each id[_n=1] is the start of
// a gapless panel
// maxT is variable containing the t steps for that gapless id 
capture program drop draw_states
program def draw_states
version 16.1
args id date runt maxT M pRevMEM qrr qcc wR wC
	quietly {
	//runt is the running t for that id (without gaps), maxT is the max T of runt for that id
	//so local max_maxT is the largest maxT needed to run through
	quietly sum `maxT'
	local max_maxT = r(max)
	
	//Generate variables and intital draw
	
	forvalues m=1/`M' {
		tempvar rvar_`m'
		
		capture drop R_`m'
		gen byte R_`m' =.
		gen `rvar_`m'' = runiform()
		
		
		replace R_`m'= 1 if `rvar_`m''<=`pRevMEM' &  `runt' ==1 
		replace R_`m'= 0 if ccdebt ==0 &  `runt' ==1
		replace R_`m' = 0 if `rvar_`m''>`pRevMEM' & !missing(`rvar_`m'') &  `runt' ==1
		
		capture drop nextR_`m'
		gen byte nextR_`m' =. //predefine the next variable
	}	
	
	 //Calculate given Rnow whether given qrr qcc transition to 1 or 0 in Rnext
	
	tempvar touse
	capture drop `touse'
	gen byte `touse' =0
	replace `touse' = 1 if `runt'==1 	
	
	quietly describe R_*, varlist
	local allRs "`r(varlist)'"
	quietly describe nextR_*, varlist
	local allRsnext "`r(varlist)'"
	
	
	mata: DrawNextR("`allRs'", "`allRsnext'", "`touse'", `qrr', `qcc')
	
	//Likely faster if loop in Mata, should be almost as easy
	forvalues tt = 2/`max_maxT' {
		
	
		quietly replace `touse' =0
		quietly replace `touse' = 1 if `runt'==`tt'
		forvalues m=1/`M' {
			quietly replace R_`m'= nextR_`m'[_n-1] if `touse' ==1
		}
		
		mata: DrawParticles("`allRs'", "`wR'", "`wC'", "`touse'") 
		mata: DrawNextR("`allRs'", "`allRsnext'", "`touse'", `qrr', `qcc')
		
	}
	
	/*
		//Define a wide multiple imputation
		capture drop R_`m'
		gen byte R_`m' =.
		sort `id' `date'
		//Draw revolving state for t =1 for each person
		capture drop rvar
		tempvar rvar
		gen `rvar' = runiform()
		//Set initial value drawing from initial probability 
		
		replace R_`m'= 1 if `rvar'<=`pR0' 
		replace R_`m'= 0 if ccdebt ==0
		replace R_`m' = 0 if `rvar'>`pR0' & !missing(`rvar')
	}
	*/
	}
end


/*** Code to test forward calc 
use  "$OUTDIR/MEM_CCP_ccard_prepped.dta", clear
//Discard observations without an open CC
keep if openCC >0 & openCC <.

	//Set sample and calculate panel
	//Create a new id varaible stored in id_2 that is does not have any panel gaps

	nogap_id consumer_nb date id2 3

	//Calculate maximum length of t iterations
	tempvar runt maxT
	sort  id2 date
	by id2: gen runt = _n
	by id2: egen maxT = max(runt)
	
	//Clear state 
	capture drop pRf
	capture drop pCf //should alwasy be 1-pRf
	capture drop pR0
	
	//capture mi unset
	quietly xtset id2 date, delta(3)

	//Initialize states 
	// pR0 contains estimate of initial state
	gen pR0=pRevMEM
	gen pRf = pR0
	gen pCf = 1-pRf

local model_rev Bln_ccdebt100  Ba1 Ba2 Ba3 L.Bln_ccdebt100  L.Bln_cclimit100

local model_con D.Bln_ccdebt100  Ba1 Ba2 Ba3  


		reg `model_rev' [aw=pRf]
		local sigma_e_rev = e(rmse)
		disp "`sigma_e_rev'"
		capture drop rev_resid
		predict rev_resid, resid
		
		reg `model_con' [aw=pCf]
		local sigma_e_con = e(rmse)
		disp "`sigma_e_con'"
		capture drop con_resid
		predict con_resid, resid

		//Calculate density for each model and weight
		capture drop fidR fidC
		gen double fidR = pR0*normalden(rev_resid,`sigma_e_rev') if !missing(rev_resid) & !missing(con_resid)
		gen double fidC = (1-pR0)*normalden(con_resid,`sigma_e_con') if !missing(rev_resid) & !missing(con_resid)	
		
		/*** use forward algorithm to make new prediction of probility in each state ****/
		
*/
capture mata: mata drop ForwardCalc()
mata:
	//Given weights, sample from current R with replacement to draw next particles
	void ForwardCalc(string scalar pRf_st, string scalar LpRf_st, string scalar fidR_st, string scalar fidC_st, scalar qrr, scalar qcc, string scalar touse) 
		{
			real matrix 		pRf, LpRf, fidR, fidC
			real matrix			P_S1, P_X1
			
			
			st_view(pRf=., ., pRf_st,touse)
			st_view(LpRf=., ., LpRf_st,touse)
			st_view(fidR=., ., fidR_st,touse)
			st_view(fidC=., ., fidC_st,touse)
			
			
			//Extrapolate state forward using transistion matrix
			//Likelihood next state r give r last period, r given c last period
			P_S1 = qrr*LpRf + (1-qcc)*(J(rows(LpRf),cols(LpRf),1)-LpRf) 
			
			//Predict next observation
			P_X1 = fidR :* P_S1 + fidC:*(J(rows(P_S1),cols(P_S1),1)-P_S1)
			
			//Condition S1 on X1
			pRf[.,.] = (fidR :* P_S1) :/ P_X1

		}
	end
	
//Calculate probability of R or C using forward algorithm given current estimates 
// assuming ccdebt =0 ->R=0
// Uses densities stored in varibles fidR and fidC
// Writes over pRf
// Takes pR0 the initial estimate
// Assumes not gaps in id date (run nogap_id to ensure) so each id[_n=1] is the start of
// a gapless panel
// maxT is variable containing the t steps for that gapless id 
capture program drop forward_calc
program def forward_calc
version 16.1
args id date runt maxT pR0 qrr qcc fidR fidC
	quietly {
	//runt is the running t for that id (without gaps), maxT is the max T of runt for that id
	//so local max_maxT is the largest maxT needed to run through
	quietly sum `maxT'
	local max_maxT = r(max)
	
	//Generate variables and intital draw
	
	 //Calculate given Rnow whether given qrr qcc transition to 1 or 0 in Rnext
	
	tempvar touse
	capture drop `touse'
	gen byte `touse' =0

	capture drop pRf
	gen pRf = `pR0'
	capture drop LpRf
	gen LpRf = L.pRf
	

	//Likely faster if loop in Mata, should be almost as easy
	forvalues tt = 2/`max_maxT' {
		
	
		quietly replace `touse' =0
		quietly replace `touse' = 1 if `runt'==`tt'
		
		//Put lagged value, updated in previous iteration in LpRf
		replace LpRf = L.pRf if `touse' == 1
		
		mata: ForwardCalc("pRf", "LpRf", "fidR", "fidC", `qrr', `qcc', "`touse'")
		
		
	}
	

	}
end		
		
//		forward_calc id2 date  runt maxT pR0 .8 .6 fidR fidC

	
//Calculate residuals given model, coefficients stored in matrix `e(b)'
//store residuals in resid, will write over resid
capture program drop calculate_residuals
program def calculate_residuals
version 16.1
args  model eb resid
	tempname b
	matrix `b' = `eb'
	local depvar = word("`model'", 1)
	local ncoef = wordcount("`model'") //Include constant
	local predstring 0
	forvalues xx=1/`ncoef' { //first word is dep variable, but also include constant
		local thisnum = `xx'+1
		if `thisnum' < `ncoef' {
			local thiscoef = word("`model'", `thisnum')
		}
		else {
			local thiscoef = 1
		}
		local predstring `predstring' + `b'[1,`xx']*`thiscoef'
	}
	capture drop `resid'
	quietly gen `resid' = `depvar' - (`predstring')
end



//Estimate the transition probabilities
//With a set of M sequences of revolving for each id, takes these transitions
//and estimates at transition matrix
//returns r(qrr) and r(qcc)
//args M (the number of sequences drawn) and the variable `R'_m each is stored in
capture program drop estimate_transition
program def estimate_transition, rclass
version 16.1
args id date M R
	tempvar L_R 
	sort `id' `date'
	local qrr =0
	local qcc =0
	//Initialize states 
	forvalues m=1/`M' {
		capture drop `L_R'
		quietly by `id': gen byte `L_R' = L.R_`m'
		quietly sum R_`m' if `L_R'==1
		local qrr = `qrr' + r(mean)
		quietly sum R_`m' if `L_R'==0
		local qcc = `qcc' + (1-r(mean))
	}
	return local qrr = `qrr'/`M'
	return local qcc = `qcc'/`M'
end

//Estimate the residual variance
//Calculate average root mean squared error from multipiple imputation
//calculates average resid using each of R_`m' if R_`m' ==`ifR'
capture program drop mi_rmse
program def mi_rmse, rclass
version 16.1
args resid M ifR
	local MSE =0 
	tempvar tempsquare
	quietly forvalues m=1/`M' {
		tempvar tempsquare
		capture drop `tempsquare'
		sum `resid' if R_`m' == `ifR'
		gen `tempsquare' = (`resid'-`r(mean)')^2
		sum `tempsquare'
		local MSE = `MSE'+`r(mean)'/`M'
	}
	return local rmse = sqrt(`MSE')

end



	

capture mata: mata drop DrawNextR()
mata:
//Go from initial draw in runt =1 to runt=2 with transition given by qrr qcc
	void DrawNextR(string scalar allRs, string scalar allRsnext, string scalar touse, real scalar qrr, real scalar qcc) 
	{
		string rowvector	Rvars, Rvarsnext
		real matrix 		Rnow, Rnext
		real matrix			rdraw, Rcc, Rrr
		Rvars = tokens(allRs)
		Rvarsnext = tokens(allRsnext)
		
		st_view(Rnow=., ., Rvars,touse)
		st_view(Rnext=., ., Rvarsnext,touse)
		//Gen matrix of of Rnow size uniform draws
		rdraw=runiform(rows(Rnow),cols(Rnow))
		Rcc = rdraw :<J(rows(rdraw),cols(rdraw),qcc)
		Rrr = rdraw :<J(rows(rdraw),cols(rdraw),qrr)
		Rnext[.,.] = Rnow :* Rrr :+ !Rnow :* Rcc 
	}
end

capture mata: mata drop DrawParticles()
mata:
	//Given weights, sample from current R with replacement to draw next particles
	void DrawParticles(string scalar allRs, string scalar weightR, string scalar weightC, string scalar touse) 
		{
			string rowvector	Rvars
			real scalar			M, ii, jj
			real matrix 		Rnow, Rnew
			real matrix			wR, wC
			real matrix 		weight, weightsum, cumweight, rdraw, testsum, test 
			
			Rvars = tokens(allRs)
			
			st_view(Rnow=., ., Rvars,touse)
			st_view(wR=., ., weightR,touse)
			st_view(wC=., ., weightC,touse)
			Rnew =Rnow //Populate Rnew
			M = cols(Rnow)
			//Create weights
			weight = Rnow :* J(1,M,wR) + (J(rows(Rnow),cols(Rnow),1)-Rnow) :* J(1,M,wC) 
			weightsum = rowsum(weight)
			//Normalize to sum to one
			weight = weight :/ J(1,cols(weight),weightsum)
			//Create running weight sum
			cumweight = weight
			for (ii=2; ii<=M; ii++) {
				cumweight[., ii] = cumweight[.,ii] + cumweight[.,ii-1]
			}
			rdraw=runiform(rows(Rnow),cols(Rnow))
			
			//Pre-populate
			testsum = J(rows(Rnow),cols(Rnow),1)

			for (ii=1; ii<=M; ii++) {
				test = rdraw[.,ii] :<= cumweight
				testsum[.,ii]=J(rows(test),1, M+1)-rowsum(test)
				for (jj=1;jj<=rows(Rnow); jj++) {
						Rnew[jj,ii] = Rnow[jj,testsum[jj, ii] ]
				}
			}
			Rnow =Rnew //Save Rnew to write over Rnow
		}
end

	
/*** Calculate log likelihood ***/
capture prog drop calculate_likelihood 
program def calculate_likelihood , rclass
	args fidR fidC M 
	tempvar ln_fidR ln_fidC
	quietly gen `ln_fidR' = ln(fidR)
	quietly gen `ln_fidC' = ln(fidC)
	local lnf =0
	forvalues mm = 1/`M' {
		tempvar lnf_`mm'
		quietly gen `lnf_`mm''=R_`mm'*`ln_fidR'+ (1-R_`mm')*`ln_fidC'
		quietly sum `lnf_`mm''
		local lnf=`lnf'+`r(sum)'/`M'
	}
	return local lnf= `lnf'
end
			
//calculate_likelihood fidR fidC 5	
// disp `r(lnf)'
	
	
/*** Calculate estimates for each of M sequences ***/
capture prog drop estimate_mult
program def estimate_mult , eclass
	args model_est M ifR

	forvalues mm = 1/`M' {
		quietly reg `model_est' if R_`mm' ==`ifR' 
		matrix result_`mm' = e(b)
		if `mm'==1 {
			matrix result = result_`mm'/`M'
		}
		else{
			matrix result = result + result_`mm'/`M'
		}
	}

	matrix b = result
	matrix V = e(V) //Assigne last variance matrix
	ereturn post b V
	ereturn display
end

//local model_rev Bln_ccdebt100  Ba1 Ba2 Ba3 L.Bln_ccdebt100  L.Bln_cclimit100
//estimate_mult "`model_rev'" 5 1




capture program drop regEM_conv_est
	program def regEM_conv_est, rclass
	version 16.1
	args model_rev model_con id date pR0  qrr qcc force_transition sample 
	//model_rev 	variables to include in revolver model
	//model_con 	variables to include in convenience model
	//id		 	common panel id variable
	//date 			date variable
	//pR0 			variable containing estimates of initial probility Revolving at time t==1
	//qrr 			initial guess for r to r transition
	//qcc			initial guess for c to c transition
    //force_transition whether to force the transitions to stay at qrr and qcc, 1 if yes, everything else no
	//sample		a variable that marks the sample to be included
	//Outputs: 		pRf a final estimate of the probability revolving at every time.
	//				r(qrr) r(qcc) Estimated transition probabilities
	//				Would like model_rev and model_con coefficients, but may need to run after to store

    local start_qrr `qrr'
    local start_qcc `qcc'
    
	local deltalnf = 100000
	tempvar new_prob_con rev_e con_e mylnf myfidR myfidC diff_p2 sample_rev sample_con

	quietly {
	//Set sample and calculate panel
	//Create a new id varaible stored in id_2 that is does not have any panel gaps
	tempvar id2
	nogap_id `id' `date' `id2' 3
	
	//Calculate maximum length of t iterations
	tempvar runt maxT
	sort  `id2' `date'
	by `id2': gen `runt' = _n
	by `id2': egen `maxT' = max(`runt')
	
	//Clear state 
	capture drop pRf
	capture drop pCf //should alwasy be 1-pRf
	
	//capture mi unset
	quietly xtset `id2' `date', delta(3)

	//Initialize states 
	// pR0 contains estimate of initial state
	gen pRf = `pR0'
	gen pCf = 1-pRf
	}
	
	local count =1
	while `deltalnf'>100 {
		quietly {
		//Make sure temporary variables are cleared
		/*
		foreach var in `rev_e' `con_e' `new_prob_con' `myfidR' `myfidC' `mylnf' `diff_p2' `tlnfR' `tlnfC' `sample_rev' `sample_con' {
			capture drop `var' 
		}
		*/
		capture drop rev_resid
		capture drop con_resid
		
		//Create  transition probabilities
		//Only in sample
		quietly reg `model_rev' [aw=pRf] if `sample' ==1
		local sigma_e_rev = e(rmse)
		predict rev_resid, resid
		
		quietly reg `model_con' [aw=pCf] if `sample' ==1
		local sigma_e_con = e(rmse)
		predict con_resid, resid

		//Calculate density for each model and weight
		//Includes any out of sample observations possible because predict includes those
		capture drop fidR fidC
		quietly gen double fidR = `pR0'*normalden(rev_resid,`sigma_e_rev') if !missing(rev_resid) & !missing(con_resid)
		quietly gen double fidC = (1-`pR0')*normalden(con_resid,`sigma_e_con') if !missing(rev_resid) & !missing(con_resid)

		/*
		capture drop wR wC	
		quietly gen wR = fidR/(fidR+fidC) 
		quietly gen wC = fidC/(fidR+fidC) 
		*/
		
		/*** use forward algorithm to make new prediction of probility in each state ****/
		//Includes out of sample observations if possible
		forward_calc `id2' `date'  `runt' `maxT' `pR0' `qrr' `qcc' fidR fidC
		quietly replace pCf = 1 -pRf
		
		/*** Calculate overall likelihood ***/
		//Only for sample
			//Combine for overall prob
		capture drop `lnf'
		tempvar lnf
		quietly gen double `lnf' = (pRf)*ln(fidR)+(1-pRf)*ln(fidC) if !missing(rev_resid) & !missing(con_resid) & `sample' ==1
		quietly sum `lnf'
		local total_lnf = `r(sum)'
        
		//Update transitions
        if "`force_transition'" =="1" {
            local qrr = `start_qrr'
            local qcc = `start_qcc'
        }
        else {
                
            capture drop pRR
            capture drop pCC
            quietly gen pRR= pRf*L.pRf if `sample' ==1
            quietly sum pRR if `sample' ==1
            local pRR = `r(mean)'
            quietly sum L.pRf if `sample' ==1
            local qrr = `pRR'/`r(mean)'
            
            quietly gen pCC= (pCf)*(L.pCf) if `sample' ==1
            quietly sum pCC if `sample' ==1
            local pCC = `r(mean)'
            quietly sum (L.pCf) if `sample' ==1
            local qcc = `pCC'/`r(mean)'		
        }
		
		
		if `count' >1 {
			//Compare to previous
			local deltalnf = abs(`total_lnf'-`old_lnf') 
			//Store for next round
			
	
		}
		}
		disp "*****Iteration `count': log likelihood " `total_lnf' "  *****"
		
		local old_lnf = `total_lnf' 
		
		
		local count = `count'+1
		
		
	}

	return local qrr = `qrr'
	return local qcc = `qcc'
end


use  "$OUTDIR/MEM_CCP_ccard_prepped.dta", clear
//Discard observations without an open CC
keep if openCC >0 & openCC <.
svyset [pw=weight]

capture drop pConvageMEM
logit convMEM a1 a2 a3
predict pConvageMEM, pr
matrix blCMEMage = e(b)

capture drop pConvuseMEM
logit convMEM ccuse ccuse2 ccuse3
predict pConvuseMEM, pr
matrix blCMEMuse = e(b)

capture drop pConvMEM
capture drop pRevMEM
logit convMEM ccuse ccuse2 ccuse3 a1 a2 a3
predict pConvMEM, pr
matrix blCMEMuseage = e(b)
gen pRevMEM = 1-pConvMEM 


capture drop nonMEMsample
gen nonMEMsample =1
replace nonMEMsample =0 if inMEM ==1



/**** Do variations of model for credit and debt  */

capture drop probi_rev*
capture drop probi_con*

//Log debt and credit with individual mean removed 
local model_rev1 Bln_ccdebt100 Ba1  Ba2 Ba3 L.Bln_ccdebt100  L.Bln_cclimit100 
local model_con1 D.Bln_ccdebt100 Ba1 Ba2 Ba3 

//Debt and Credit with individual mean removed .
local model_rev2 Bccdebt  Ba1 Ba2 Ba3 L.Bccdebt  L.Bcclimit 
local model_con2 D.Bccdebt  Ba1 Ba2 Ba3  

//Debt and Credit .
local model_rev3 Bccdebt  Ba1 Ba2 Ba3 L.Bccdebt  L.Bcclimit 
local model_con3 Bccdebt  Ba1 Ba2 Ba3 

//Utilization 
local model_rev4 Bccuse  Ba1 Ba2 Ba3 L.Bccuse 
local model_con4 D.Bccuse Ba1 Ba2 Ba3 

//Utilization 
local model_rev5 Bccuse  Ba1 Ba2 Ba3 L.Bccuse 
local model_con5 Bccuse  Ba1 Ba2 Ba3 

//Model 1, but force transition to match SCPC
local model_rev6 Bln_ccdebt100 Ba1  Ba2 Ba3 L.Bln_ccdebt100  L.Bln_cclimit100 
local model_con6 D.Bln_ccdebt100 Ba1 Ba2 Ba3 


foreach model in 1 2 3 4 5 6 {
	local force_transition 0
    if `model' ==6 {
        	local force_transition 1
    }
	disp "****Model `model' ***** "
	disp "Revolver: `model_rev`model''"
	disp "Conv: `model_con`model''"

	regEM_conv_est "`model_rev`model''"  "`model_con`model''"  consumer_nb date   pRevMEM  $init_pRR $init_pCC `force_transition' nonMEMsample
    local qrr`model' = r(qrr)
    local qcc`model' = r(qcc)
    disp "***** Transitions "
    disp "qrr = `qrr`model''"
    disp "qcc = `qcc`model''"
	
	disp "**** Fraction Revolver"
	sum pRf
	
	gen prob_rev`model' = pRf
	gen prob_con`model' = 1-pRf


		
	/*From an SCF logit of how convenience is related to utilization*/ 
	local logitConvuseSCF  1.632 + -8.764*x + 8.354*x^2 -3.327*x^3 

	twoway (lpoly   prob_rev`model'  ccuse if ccuse< 1.1) ///
	(function y = 1- exp(blCMEMuse[1,"convMEM:_cons"]+ ///
			   blCMEMuse[1,"convMEM:ccuse"]*x + ///
			   blCMEMuse[1,"convMEM:ccuse2"]*x^2 + ///
			   blCMEMuse[1,"convMEM:ccuse3"]*x^3) ///
			   / (1+exp( ///
			   blCMEMuse[1,"convMEM:_cons"]+ ///
			   blCMEMuse[1,"convMEM:ccuse"]*x + ///
			   blCMEMuse[1,"convMEM:ccuse2"]*x^2 + ///
			   blCMEMuse[1,"convMEM:ccuse3"]*x^3) ///
			   ), range(0 1.1) lpattern(dash)) ///
		/*(function y = 1- ///
		   exp(`logitConvuseSCF')/ ///
		  (1+exp(`logitConvuseSCF')), range(0 1.1) lpattern(dash_dot)) */ ///
		,  xtitle(Credit Utilization) ytitle(Fraction revolving) name(ccuse_prob_revEM`model', replace) ///
		legend(on rows(1) order(- "Fraction revolving:" 1 2 3) label(1 "EM estimates") label(2 "MEM logit") label(3 "SCF logit"))
	graph export "$OUTDIR/ccuse_prob_revEM`model'.pdf", as(pdf) font(Times) replace name(ccuse_prob_revEM`model')

	/*From an SCF logit of how convenience is related to age*/ 
	local logitAgeSCF .0972 + 2.0502*((x-50)/50) + .15434*((x-50)/50)^2  -.121636*((x-50)/50)^3

	twoway (lpoly prob_rev`model'  age) ///
	(function y =  1- exp(blCMEMage[1,"convMEM:_cons"]+ ///
			   blCMEMage[1,"convMEM:a1"]*((x-50)/50) + ///
			   blCMEMage[1,"convMEM:a2"]*((x-50)/50)^2 + ///
			   blCMEMage[1,"convMEM:a3"]*((x-50)/50)^3) ///
			   / (1+exp( ///
			   blCMEMage[1,"convMEM:_cons"]+ ///
			   blCMEMage[1,"convMEM:a1"]*((x-50)/50) + ///
			   blCMEMage[1,"convMEM:a2"]*((x-50)/50)^2 + ///
			   blCMEMage[1,"convMEM:a3"]*((x-50)/50)^3) ///
			   ), range(20 80) lpattern(dash)) /// 
			  /* (function y = 1- ///
			   exp(`logitAgeSCF')/ ///
			(1+exp(`logitAgeSCF')), range(20 80) lpattern(dash_dot)) */ , ///
		legend(on rows(1) order(- "Fraction revolving:" 1 2 3) label(1 "EM estimates") label(2 "MEM logit") /*label(3 "SCF logit")*/) name(prev_MEM`model', replace)  xtitle(Age) ytitle(Fraction revolving)
	graph export "$OUTDIR/frac_rev_MEM`model'.pdf", as(pdf) font(Times) replace name(prev_MEM`model')
	//shell ps2pdfwr -dEPSCrop frac_con_SCF.eps frac_con_SCF.pdf


	twoway (lpoly ccuse age [aweight = prob_con`model']) (lpoly ccuse age [aweight = prob_rev`model'], lpattern(dash)) (lpoly ccuse age, lwidth(thick)),   /// 
		name(RevCon_age`model', replace)	xtitle(Age) ytitle(Credit utilization) ///
		legend(label(1 "Convenience users") label(2 "Revolvers") label(3 "Overall utilization"))
	graph export "$OUTDIR/RevCon_utilization_age`model'.pdf", as(pdf) font(Times) replace name(RevCon_age`model')
	//shell ps2pdfwr -dEPSCrop RevCon_utilization_age.eps RevCon_utilization_age.pdf


	twoway (kdensity prob_rev`model'  ) /// 
		(kdensity pRevMEM , lpattern(dash)) /// 
		, by(revMEM, note("")) ///
		legend(label(1 "EM prediction") label(2 "Age and utilization logit alone")) xtitle(Predicted probability revolving) ///
		name(rev_density_MEM`model', replace)
	graph export "$OUTDIR/rev_density_MEM`model'.pdf", as(pdf) font(Times) replace name(rev_density_MEM`model')
}

/***** Model comparison for table ****/
disp "MEM fraction revolving: "
svy: mean revMEM
foreach model in 1 2 3 4 5 6 {
	
	disp "****Model `model' ***** "
	disp "Revolver: `model_rev`model''"
	disp "Conv: `model_con`model''"

	quietly sum prob_rev`model' 
	disp "Fraction revolving: `r(mean)'"	
    disp "***** Transitions "
    disp "qrr = `qrr`model''"
    disp "qcc = `qcc`model''"
    
	capture drop errorMEM`model'
	quietly gen errorMEM`model' = (prob_rev`model' -revMEM)^2
	disp "Mean squared error:"
	svy: mean errorMEM`model'

}
/*** Plot results ***/
foreach model in 1 2 3 4 5 6 {
	
	
	/*From an SCF logit of how convenience is related to utilization*/ 
	local logitConvuseSCF  1.632 + -8.764*x + 8.354*x^2 -3.327*x^3 

	twoway (lpoly   prob_rev`model'  ccuse if ccuse< 1.1) ///
	(function y = 1- exp(blCMEMuse[1,"convMEM:_cons"]+ ///
			   blCMEMuse[1,"convMEM:ccuse"]*x + ///
			   blCMEMuse[1,"convMEM:ccuse2"]*x^2 + ///
			   blCMEMuse[1,"convMEM:ccuse3"]*x^3) ///
			   / (1+exp( ///
			   blCMEMuse[1,"convMEM:_cons"]+ ///
			   blCMEMuse[1,"convMEM:ccuse"]*x + ///
			   blCMEMuse[1,"convMEM:ccuse2"]*x^2 + ///
			   blCMEMuse[1,"convMEM:ccuse3"]*x^3) ///
			   ), range(0 1.1) lpattern(dash)) ///
		/*(function y = 1- ///
		   exp(`logitConvuseSCF')/ ///
		  (1+exp(`logitConvuseSCF')), range(0 1.1) lpattern(dash_dot)) */ ///
		,  xtitle(Credit Utilization) ytitle(Fraction revolving) name(ccuse_prob_revEM`model', replace) ///
		legend(on rows(1) order(- "Fraction revolving:" 1 2 3) label(1 "EM estimates") label(2 "MEM logit") /*label(3 "SCF logit") */)
	graph export "$OUTDIR/ccuse_prob_revEM`model'.pdf", as(pdf) font(Times) replace name(ccuse_prob_revEM`model')

	/*From an SCF logit of how convenience is related to age*/ 
	local logitAgeSCF .0972 + 2.0502*((x-50)/50) + .15434*((x-50)/50)^2  -.121636*((x-50)/50)^3

	twoway (lpoly prob_rev`model'  age) ///
	(function y =  1- exp(blCMEMage[1,"convMEM:_cons"]+ ///
			   blCMEMage[1,"convMEM:a1"]*((x-50)/50) + ///
			   blCMEMage[1,"convMEM:a2"]*((x-50)/50)^2 + ///
			   blCMEMage[1,"convMEM:a3"]*((x-50)/50)^3) ///
			   / (1+exp( ///
			   blCMEMage[1,"convMEM:_cons"]+ ///
			   blCMEMage[1,"convMEM:a1"]*((x-50)/50) + ///
			   blCMEMage[1,"convMEM:a2"]*((x-50)/50)^2 + ///
			   blCMEMage[1,"convMEM:a3"]*((x-50)/50)^3) ///
			   ), range(20 80) lpattern(dash)) /// 
			  /* (function y = 1- ///
			   exp(`logitAgeSCF')/ ///
			(1+exp(`logitAgeSCF')), range(20 80) lpattern(dash_dot)) */ , ///
		legend(on rows(1) order(- "Fraction revolving:" 1 2 3) label(1 "EM estimates") label(2 "MEM logit") /*label(3 "SCF logit")*/) name(prev_MEM`model', replace)  xtitle(Age) ytitle(Fraction revolving)
	graph export "$OUTDIR/frac_rev_MEM`model'.pdf", as(pdf) font(Times) replace name(prev_MEM`model')
	//shell ps2pdfwr -dEPSCrop frac_con_SCF.eps frac_con_SCF.pdf


	twoway (lpoly ccuse age [aweight = prob_con`model']) (lpoly ccuse age [aweight = prob_rev`model'], lpattern(dash)) (lpoly ccuse age, lwidth(thick)),   /// 
		name(RevCon_age`model', replace)	xtitle(Age) ytitle(Credit utilization) ///
		legend(label(1 "Convenience users") label(2 "Revolvers") label(3 "Overall utilization"))
	graph export "$OUTDIR/RevCon_utilization_age`model'.pdf", as(pdf) font(Times) replace name(RevCon_age`model')
	//shell ps2pdfwr -dEPSCrop RevCon_utilization_age.eps RevCon_utilization_age.pdf


	twoway (kdensity prob_rev`model'  ) /// 
		(kdensity pRevMEM , lpattern(dash)) /// 
		, by(revMEM, note("")) ///
		legend(label(1 "EM prediction") label(2 "Age and utilization logit alone")) xtitle(Predicted probability revolving) ///
		name(rev_density_MEM`model', replace)
	graph export "$OUTDIR/rev_density_MEM`model'.pdf", as(pdf) font(Times) replace name(rev_density_MEM`model')
}


/*** Output for paper ***/
cd "$OUTDIR"
 
save CCP_MEM_estimates, replace 	 




