clear all
set more off, permanently
set varabbrev off , permanently
set matsize 8000
set scheme s1color, permanently
graph set window fontface "Liberation Serif"


/*** Directory structure 
Replace with appropriate directory structure.
**/
global CCPPANEL "/PanelData/"
global ROOTDIR "/Credit_cards/Revolver"
local INDIR "$ROOTDIR/Intermediate/"
local PROGDIR "$ROOTDIR/Programs/"
global OUTDIR "$ROOTDIR/Intermediate/"
global MEMDIR "MakingEndsMeet/Data"

capture log close
cd "`PROGDIR'"
log using CC_EM_4.txt_12-22-2021, replace text

/*************
Project: Credit Card Use Create EM
Programmer: Scott Fulford
Date: 9/12/2015 On Fed/Equifax
12/16/2019 on CFPB CCP


*************/



/*** Output for paper ***/
cd "$OUTDIR"
 

 
use  "$OUTDIR/MEM_CCP_ccard_prepped.dta", clear
//Discard observations without an open CC
keep if openCC >0 & openCC <.
svyset [pw=weight]

capture drop pConvageMEM
logit convMEM a1 a2 a3
predict pConvageMEM, pr
matrix blCMEMage = e(b)

capture drop pConvuseMEM
logit convMEM ccuse ccuse2 ccuse3
predict pConvuseMEM, pr
matrix blCMEMuse = e(b)

capture drop pConvMEM
capture drop pRevMEM
logit convMEM ccuse ccuse2 ccuse3 a1 a2 a3
predict pConvMEM, pr
matrix blCMEMuseage = e(b)
gen pRevMEM = 1-pConvMEM 


capture drop nonMEMsample
gen nonMEMsample =1
replace nonMEMsample =0 if inMEM ==1

cd "$OUTDIR"
use CCP_MEM_estimates, clear


/*** Plot results ***/
foreach model in 1 2 3 4 5 6 {
	
	
	/*From an SCF logit of how convenience is related to utilization*/ 
	local logitConvuseSCF  1.632 + -8.764*x + 8.354*x^2 -3.327*x^3 

	twoway (lpoly   prob_rev`model'  ccuse if ccuse< 1.1) ///
	(function y = 1- exp(blCMEMuse[1,"convMEM:_cons"]+ ///
			   blCMEMuse[1,"convMEM:ccuse"]*x + ///
			   blCMEMuse[1,"convMEM:ccuse2"]*x^2 + ///
			   blCMEMuse[1,"convMEM:ccuse3"]*x^3) ///
			   / (1+exp( ///
			   blCMEMuse[1,"convMEM:_cons"]+ ///
			   blCMEMuse[1,"convMEM:ccuse"]*x + ///
			   blCMEMuse[1,"convMEM:ccuse2"]*x^2 + ///
			   blCMEMuse[1,"convMEM:ccuse3"]*x^3) ///
			   ), range(0 1.1) lpattern(dash)) ///
		/*(function y = 1- ///
		   exp(`logitConvuseSCF')/ ///
		  (1+exp(`logitConvuseSCF')), range(0 1.1) lpattern(dash_dot)) */ ///
		,  xtitle(Credit Utilization) ytitle(Fraction revolving) name(ccuse_prob_revEM`model', replace) ///
		legend(on rows(1) order(- "Fraction revolving:" 1 2 3) label(1 "HMM estimates") label(2 "MEM logit") /*label(3 "SCF logit") */)
	graph export "$OUTDIR/ccuse_prob_revEM`model'.pdf", as(pdf) font(Times) replace name(ccuse_prob_revEM`model')

	/*From an SCF logit of how convenience is related to age*/ 
	local logitAgeSCF .0972 + 2.0502*((x-50)/50) + .15434*((x-50)/50)^2  -.121636*((x-50)/50)^3

	twoway (lpoly prob_rev`model'  age) ///
	(function y =  1- exp(blCMEMage[1,"convMEM:_cons"]+ ///
			   blCMEMage[1,"convMEM:a1"]*((x-50)/50) + ///
			   blCMEMage[1,"convMEM:a2"]*((x-50)/50)^2 + ///
			   blCMEMage[1,"convMEM:a3"]*((x-50)/50)^3) ///
			   / (1+exp( ///
			   blCMEMage[1,"convMEM:_cons"]+ ///
			   blCMEMage[1,"convMEM:a1"]*((x-50)/50) + ///
			   blCMEMage[1,"convMEM:a2"]*((x-50)/50)^2 + ///
			   blCMEMage[1,"convMEM:a3"]*((x-50)/50)^3) ///
			   ), range(20 80) lpattern(dash)) /// 
			  /* (function y = 1- ///
			   exp(`logitAgeSCF')/ ///
			(1+exp(`logitAgeSCF')), range(20 80) lpattern(dash_dot)) */ , ///
		legend(on rows(1) order(- "Fraction revolving:" 1 2 3) label(1 "HMM estimates") label(2 "MEM logit") /*label(3 "SCF logit")*/) name(prev_MEM`model', replace)  xtitle(Age) ytitle(Fraction revolving)
	graph export "$OUTDIR/frac_rev_MEM`model'.pdf", as(pdf) font(Times) replace name(prev_MEM`model')
	//shell ps2pdfwr -dEPSCrop frac_con_SCF.eps frac_con_SCF.pdf


	twoway (lpoly ccuse age [aweight = prob_con`model']) (lpoly ccuse age [aweight = prob_rev`model'], lpattern(dash)) (lpoly ccuse age, lwidth(thick)),   /// 
		name(RevCon_age`model', replace)	xtitle(Age) ytitle(Credit utilization) ///
		legend(label(1 "Convenience users") label(2 "Revolvers") label(3 "Overall utilization"))
	graph export "$OUTDIR/RevCon_utilization_age`model'.pdf", as(pdf) font(Times) replace name(RevCon_age`model')
	//shell ps2pdfwr -dEPSCrop RevCon_utilization_age.eps RevCon_utilization_age.pdf


	twoway (kdensity prob_rev`model'  ) /// 
		(kdensity pRevMEM , lpattern(dash)) /// 
		, by(revMEM, note("")) ///
		legend(label(1 "HMM prediction") label(2 "Age and utilization logit alone")) xtitle(Predicted probability revolving) ///
		name(rev_density_MEM`model', replace)
	graph export "$OUTDIR/rev_density_MEM`model'.pdf", as(pdf) font(Times) replace name(rev_density_MEM`model')
}



/*** Create some simulation statistics to test ***/

sum ln_ccdebt100
gen rln_ccdebt100 = rnormal(`r(mean)',`r(sd)')
sum ln_cclimit100
gen rln_cclimit100 = rnormal(`r(mean)',`r(sd)')



/*** Calclate ROC curves for all models ****/
use CCP_MEM_estimates, clear

keep if !missing(revMEM)
gen prob_rev7 =pRevMEM //assign model 7 to MEM logit
//Calculate curves
foreach model in 1 2 3 4 5 6 7 {
    senspec revMEM prob_rev`model', sensitivity(tprate`model') fpos(fprate`model')
    display "***ROC area for Model `model'"
    roctab revMEM prob_rev`model'
    
}
keep tprate* fprate*


tempfile allroc
save allroc, replace
save `allroc', replace
foreach model in 1 2 3 4 5 6 7 {
    use `allroc', clear
    keep tprate`model' fprate`model'
    rename tprate`model' tprate
    rename fprate`model' fprate
    sort fprate tprate
    gen model = `model'
    tempfile roc`model'
    save `roc`model'', replace
}

use `roc1', clear
foreach model in 2 3 4 5 6 7 {
     append using `roc`model''
     
}

//Generate 45 degree line
gen tpratend = fprate if model ==1

twoway (line tprate fprate if model ==1) ///
    /// (line tprate fprate if model ==2, lpattern(dash)) ///
    /// (line tprate fprate if model ==3, lpattern(dash_dot)) ///
    (line tprate fprate if model ==4, lpattern(dash) ) ///   
    /// (line tprate fprate if model ==5, lpattern(dash_dot)) ///
    (line tprate fprate if model ==6, lpattern(longdash)) /// longdash --..
    /// (line tprate fprate if model ==7, lpattern("--..")) /// longdash --..
    (line tpratend fprate if model ==1, lpattern(dash) lcolor(gray)),   ///
    xtitle(False positive rate) ytitle(True positive rate) ///
    xsize(4) ysize(4) ///
    legend(on cols(3) order(1 2 3) label(1 "Model 1") label(2 "Model 4" ) /*label(3 "Model 5" )*/ label(3 "Model 6" ) /*label(5 "logit" ) label(6 "Model 6")*/ ) ///
    name(ROCcurves, replace)
graph export "$OUTDIR/ROCcurves.pdf", as(pdf) font(Times) replace name(ROCcurves)

use CCP_MEM_estimates, clear

	
/**** Model for paper output ****/

local model_rev Bln_ccdebt100  Ba1 Ba2 Ba3 L.Bln_ccdebt100  L.Bln_cclimit100
local model_con D.Bln_ccdebt100  Ba1 Ba2 Ba3  

/*
	regEM_conv_est "`model_rev'"  "`model_con'"  consumer_nb date   pRevMEM  .75 .75 nonMEMsample
	capture drop pCf
	gen pCf =1 -pRf
    local qrr = r(qrr)
    local qcc = r(qcc)
    disp "***** Transitions "
    disp "qrr = `qrr'"
    disp "qcc = `qcc'"
  */
  capture drop pCf
  replace pRf = prob_rev1
	gen pCf =1 -pRf
  
    xtset consumer_nb date, delta(3)
	reg `model_con' [aweight =pCf] if nonMEMsample ==1
	
	sum ccuse [aweight =pCf] if e(sample)
	outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Conv Model) addstat(Utilization, `r(mean)') ///
	 replace //FIRST rgression
	matrix Con_xb = e(b)
	reg `model_rev' [aweight =pRf] if nonMEMsample ==1
	outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Rev Model) 
	matrix Rev_xb = e(b)
sum pRf



twoway (lpoly pCf age if nonMEMsample ==1), xtitle(Age) ytitle(Fraction convenience users) name(frac_con_full, replace) 
//graph export frac_con_full.eps, as(eps) font(Times) replace name(frac_con_full)
//shell ps2pdfwr -dEPSCrop frac_con_full.eps frac_con_full.pdf
twoway (lpoly   pCf ccuse if ccuse< 1.1 & nonMEMsample ==1), name(ccuse_prob_convpr, replace)



	 
reg Bln_ccdebt Ba1 Ba2 Ba3 L.Bln_ccdebt  L.Bln_cclimit if openCC!=0 & nonMEMsample ==1
	 outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, All) ///
	 
 reg Bln_ccdebt Ba1 Ba2 Ba3 L.Bln_ccdebt  L.Bln_cclimit [aweight =pRf] if openCC!=0 & nonMEMsample ==1
	outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Revolver) 

 reg Bln_ccdebt Ba1 Ba2 Ba3 L.Bln_ccdebt  L.Bln_cclimit [aweight =1-pRf] if openCC!=0 & nonMEMsample ==1
	outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Convenience) 



reg Bln_ccdebt100 Ba1 Ba2 Ba3 L.Bln_ccdebt100  L.Bln_cclimit100 if openCC!=0 & nonMEMsample ==1
	 outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, All) ///
	 
 reg Bln_ccdebt100 Ba1 Ba2 Ba3 L.Bln_ccdebt100  L.Bln_cclimit100 [aweight =pRf] if openCC!=0 & nonMEMsample ==1
	outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Revolver) 

 reg Bln_ccdebt100 Ba1 Ba2 Ba3 L.Bln_ccdebt100  L.Bln_cclimit100  [aweight =1-pRf] if openCC!=0 & nonMEMsample ==1
	outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Convenience) 


//Log limit	
	reg Bln_cclimit Ba1 Ba2 Ba3 L.Bln_ccdebt  L.Bln_cclimit if openCC!=0 & nonMEMsample ==1
	 outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, All) 
	 reg Bln_cclimit100 Ba1 Ba2 Ba3 L.Bln_ccdebt100  L.Bln_cclimit100 if openCC!=0 & nonMEMsample ==1
	 outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, All) 
 	reg Bln_cclimit100 Ba1 Ba2 Ba3 L.Bln_ccdebt100  L.Bln_cclimit100 [aweight =pRf] if openCC!=0 & nonMEMsample ==1
	outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Revolver) 
	reg Bln_cclimit100 Ba1 Ba2 Ba3 L.Bln_ccdebt100  L.Bln_cclimit100 [aweight =pCf] if openCC!=0 & nonMEMsample ==1
	outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Convenience) 
	 
//Dollar level of debt 
reg Bccdebt Ba1 Ba2 Ba3 L.Bccdebt  L.Bcclimit  if openCC!=0
	 outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, All) 
reg Bccdebt Ba1 Ba2 Ba3 L.Bccdebt  L.Bcclimit [aweight =pRf] if openCC!=0 & nonMEMsample ==1
	 outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Revolver) 
reg Bccdebt Ba1 Ba2 Ba3 L.Bccdebt  L.Bcclimit [aweight =pCf] if openCC!=0
	 outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Convenience) 	 
 	 
	 
	 //Run for final output
cd "$OUTDIR"
	reg ccuse L.ccuse if openCC!=0
	outreg2  using CCP_ccutil_MLE, ///
	 excel addtext(Type, All) ///
	 replace //FIRST one
	reg ccuse L.ccuse a1 a2 a3 i.year if openCC!=0
 	outreg2  using CCP_ccutil_MLE, ///
	 excel addtext(Type, All)
	reg Bccuse  Ba1  Ba2 Ba3 L.Bccuse if openCC!=0
 	outreg2  using CCP_ccutil_MLE, ///
	 excel addtext(Type, All)
		   
	reg Bccuse  Ba1  Ba2 Ba3 L.Bccuse  [aweight =pCf]  if openCC!=0
	outreg2  using CCP_ccutil_MLE, ///
	 excel addtext(Type, Convenience)
	reg Bccuse  Ba1  Ba2 Ba3 L.Bccuse  [aweight =pRf] if openCC!=0
	outreg2  using CCP_ccutil_MLE, ///
	 excel addtext(Type, Revolver) 
	 
/* Outdated since now estimate transition matrix ***, but useful to calculate */	 
/*Descriptive statistics of transitions */
capture drop IRevolver
capture drop L4IRevolver
capture drop L8IRevolver
capture drop L16IRevolver

gen IRevolver = 3 if pRf <=.25
replace IRevolver =2 if pRf>.25 & pRf <=.75
replace IRevolver =1 if pRf>.75 & pRf <=1.5

gen LIRevolver = L.IRevolver
gen L4IRevolver = L4.IRevolver
gen L8IRevolver = L8.IRevolver
gen L16IRevolver = L16.IRevolver

tab IRevolver

tab IRevolver if LIRevolver ==1
tab IRevolver if LIRevolver ==2
tab IRevolver if LIRevolver ==3

tab IRevolver if L4IRevolver ==1
tab IRevolver if L4IRevolver ==2
tab IRevolver if L4IRevolver ==3

tab IRevolver if L8IRevolver ==1
tab IRevolver if L8IRevolver ==2
tab IRevolver if L8IRevolver ==3

tab IRevolver if L16IRevolver ==1
tab IRevolver if L16IRevolver ==2
tab IRevolver if L16IRevolver ==3

capture drop mean_pRf
capture drop IRevolve_mean
by consumer_nb: egen mean_pRf = mean(pRf)
gen IRevolver_mean = 3 if mean_pRf <=.25
replace IRevolver_mean =2 if mean_pRf>.25 & mean_pRf <=.75
replace IRevolver_mean =1 if mean_pRf>.75 & mean_pRf <=1.5

tab IRevolver_mean

capture drop likely_revolver
capture drop mean_likely_revolver
gen likely_revolver = 1 if IRevolver ==1
replace likely_revolver = 0 if IRevolver !=1 & IRevolver <.
by consumer_nb: egen mean_likely_revolver =mean(likely_revolver) if IRevolver_mean ==1
sum mean_likely_revolver



	 
twoway (lpoly pRf age if nonMEMsample ==1), xtitle(Age) ytitle(Fraction revolving) name(frac_rev, replace) 
graph export "$OUTDIR/frac_rev_util.pdf", as(pdf) font(Times) replace name(frac_rev)

/*From an SCF logit of how convenience is related to utilization*/ 
local logitConvuseSCF  1.632 + -8.764*x + 8.354*x^2 -3.327*x^3 

twoway (lpoly   pRf ccuse if ccuse< 1.1 & nonMEMsample ==1) ///
(function y = 1- exp(blCMEMuse[1,"convMEM:_cons"]+ ///
		   blCMEMuse[1,"convMEM:ccuse"]*x + ///
		   blCMEMuse[1,"convMEM:ccuse2"]*x^2 + ///
		   blCMEMuse[1,"convMEM:ccuse3"]*x^3) ///
		   / (1+exp( ///
		   blCMEMuse[1,"convMEM:_cons"]+ ///
		   blCMEMuse[1,"convMEM:ccuse"]*x + ///
		   blCMEMuse[1,"convMEM:ccuse2"]*x^2 + ///
		   blCMEMuse[1,"convMEM:ccuse3"]*x^3) ///
		   ), range(0 1.1) lpattern(dash)) ///
	(function y = 1- ///
	   exp(`logitConvuseSCF')/ ///
	  (1+exp(`logitConvuseSCF')), range(0 1.1) lpattern(dash_dot)) ///
	,  xtitle(Credit Utilization) ytitle(Fraction revolving) name(ccuse_prob_revEM, replace) ///
	legend(on rows(1) order(- "Fraction revolving:" 1 2 3) label(1 "EM estimates") label(2 "MEM logit") label(3 "SCF logit"))
graph export "$OUTDIR/ccuse_prob_revEM.pdf", as(pdf) font(Times) replace name(ccuse_prob_revEM)
//shell ps2pdfwr -dEPSCrop ccuse_prob_convEM.eps ccuse_prob_convEM.pdf

/*Create a convenience probability
Coefficients on logit estimated from SCF


gen logitConvSCF = .10847 + 2.0822*a1 + .02878*a2 + -1.0494*a3   
gen pConvSCF = exp(logitConv)/(1+exp(logitConv))
*/
/*From an SCF logit of how convenience is related to age*/ 
local logitAgeSCF .0972 + 2.0502*((x-50)/50) + .15434*((x-50)/50)^2  -.121636*((x-50)/50)^3

twoway (lpoly pRf age if nonMEMsample ==1) ///
(function y =  1- exp(blCMEMage[1,"convMEM:_cons"]+ ///
		   blCMEMage[1,"convMEM:a1"]*((x-50)/50) + ///
		   blCMEMage[1,"convMEM:a2"]*((x-50)/50)^2 + ///
		   blCMEMage[1,"convMEM:a3"]*((x-50)/50)^3) ///
		   / (1+exp( ///
		   blCMEMage[1,"convMEM:_cons"]+ ///
		   blCMEMage[1,"convMEM:a1"]*((x-50)/50) + ///
		   blCMEMage[1,"convMEM:a2"]*((x-50)/50)^2 + ///
		   blCMEMage[1,"convMEM:a3"]*((x-50)/50)^3) ///
		   ), range(20 80) lpattern(dash)) /// 
		   (function y = 1- ///
		   exp(`logitAgeSCF')/ ///
		(1+exp(`logitAgeSCF')), range(20 80) lpattern(dash_dot)), ///
	legend(on rows(1) order(- "Fraction revolving:" 1 2 3) label(1 "EM estimates") label(2 "MEM logit") label(3 "SCF logit")) name(prev_MEM, replace)  xtitle(Age) ytitle(Fraction revolving)
graph export "$OUTDIR/frac_rev_MEM.pdf", as(pdf) font(Times) replace name(prev_MEM)
//shell ps2pdfwr -dEPSCrop frac_con_SCF.eps frac_con_SCF.pdf


twoway (lpoly ccuse age [aweight = pCf] if nonMEMsample ==1) (lpoly ccuse age [aweight = 1-pRf] if nonMEMsample ==1, lpattern(dash)) (lpoly ccuse age if nonMEMsample ==1, lwidth(thick)),   /// 
	name(RevCon_age, replace)	xtitle(Age) ytitle(Credit utilization) ///
	legend(label(1 "Convenience users") label(2 "Revolvers") label(3 "Overall utilization"))
graph export "$OUTDIR/RevCon_utilization_age.pdf", as(pdf) font(Times) replace name(RevCon_age)
//shell ps2pdfwr -dEPSCrop RevCon_utilization_age.eps RevCon_utilization_age.pdf

capture  label drop revolver
label def revolver 0 "Not MEM revolver" 1 "MEM revolver"
label values revMEM revolver
twoway (kdensity pRf if nonMEMsample !=1) /// 
	(kdensity pRevMEM if nonMEMsample !=1, lpattern(dash)) /// 
	, by(revMEM, note("")) ///
	legend(label(1 "EM prediction") label(2 "Age and utilization logit alone")) xtitle(Predicted probability revolving) name(rev_density_MEM, replace)
graph export "$OUTDIR/rev_density_MEM.pdf", as(pdf) font(Times) replace name(rev_density_MEM)



/*For credit and debt with zeros
capture drop probi_con
capture drop prob_con
gen probi_con = pConvMEM
quietly sum probi_con
gen prob_con = r(mean)

local model_rev Bln_ccdebt100  Ba2 Ba3 L.Bln_ccdebt100  L.Bln_cclimit100
local model_con D.Bln_ccdebt100  Ba2 Ba3  
regEM_conv_est "`model_rev'"  "`model_con'" probi_con prob_con REVOLVER
	reg `model_con' [aweight =prob_con]
	outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Convenience) 
	matrix Con_xb = e(b)
	reg `model_rev' [aweight =1-prob_con]
	outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Revolver) 
	matrix Rev_xb = e(b)
twoway (lpoly probi_con age), xtitle(Age) ytitle(Fraction convenience users) name(frac_con_full10, replace) 
graph export "$OUTDIR/frac_con_full10.pdf", as(pdf) font(Times) replace name(frac_con_full10)

twoway (lpoly   prob_con ccuse if ccuse< 1.1), name(ccuse_prob_conv_full, replace)
*/ 


	 
/*	 
reg Bln_cclimit Ba2 Ba3 L.Bln_ccdebt10  L.Bln_cclimit 
	 outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, All) 
	reg Bln_cclimit Ba2 Ba3 L.Bln_ccdebt10  L.Bln_cclimit [aweight =probi_con]
	outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Convenience) 
 	reg Bln_cclimit Ba2 Ba3 L.Bln_ccdebt10  L.Bln_cclimit [aweight =1-probi_con]
	outreg2  using CCP_ccdebt_MLE, ///
	 excel addtext(Type, Revolver) 
*/

//Allow vary over life-cycle using standard model

/*Revolver plots*/
reg Bln_ccdebt100  cL.Bln_cclimit100 cL.Bln_cclimit100#(i.ccut0 i.ccut1 c.ccut c.ccut#c.ccut c.ccut#c.ccut#c.ccut c.age c.age#c.age c.age#c.age#c.age c.ccut#c.age c.ccut#c.ccut#c.age c.ccut#c.age#c.age c.ccut#c.ccut#c.age#c.age ) ///
		   cL.Bln_ccdebt100 c.L.Bln_ccdebt100#(i.ccut0 i.ccut1  c.ccut c.ccut#c.ccut c.ccut#c.ccut#c.ccut c.age c.age#c.age c.age#c.age#c.age c.ccut#c.age c.ccut#c.ccut#c.age c.ccut#c.age#c.age c.ccut#c.ccut#c.age#c.age) ///
	if nonMEMsample ==1 & age >=20 & age <=80 & openCC!=0 [aweight =pRf]
	
margins, nose  dydx(cL.Bln_ccdebt100)   at(age=(20(10)70) ccut=.1 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=.4 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=.7 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=.8 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=.9 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=1 ccut1=0 ccut1=0) 
matrix b_debt = r(b)'
matrix at_debt = r(at)
// margins, dydx(c.L_ln_ccdebt)  at(age=(20(10)70) ccut=0 ccut0=1 ccut1=0) at(age=(20(10)70) ccut=.1 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=.3 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=.7 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=1 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=1.1 ccut0=0 ccut1=1)
marginsplot, noci  ///
	plot1opts(msymbol(circle)) ///
	plot2opts(msymbol(diamond)) ///
	plot3opts(msymbol(triangle)) ///
	plot4opts(msymbol(square)) ///
	plot5opts(msymbol(Oh)) ///
	plot6opts(msymbol(Dh)) ///
	legend(cols(4) order(- "Utilitzation" 1 2 3 - " " 4 5 6) ///
	label(1 "0.1") label(2 "0.4") label(3 "0.7") label(4 "0.8") label(5 "0.9") label(6 "1") ) ///
	xtitle(Age) ytitle(Average marginal effect of log debt) ///
	title("") name(dyln_ccdebt, replace)
graph export "$OUTDIR/margins_lndebt_ageEM.pdf", as(pdf) font(Times) replace 
margins, nose dydx(cL.Bln_cclimit100)   at(age=(20(10)70) ccut=.1 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=.4 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=.7 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=.8 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=.9 ccut1=0 ccut1=0) at(age=(20(10)70) ccut=1 ccut1=0 ccut1=0) 
matrix b_limit = r(b)'
matrix at_limit = r(at)
marginsplot,  noci  ///
	plot1opts(msymbol(circle)) ///
	plot2opts(msymbol(diamond)) ///
	plot3opts(msymbol(triangle)) ///
	plot4opts(msymbol(square)) ///
	plot5opts(msymbol(Oh)) ///
	plot6opts(msymbol(Dh)) ///
	legend(cols(4) order(- "Utilitzation" 1 2 3 - " " 4 5 6) ///
	label(1 "0.1") label(2 "0.4") label(3 "0.7") label(4 "0.8") label(5 "0.9") label(6 "1") ) ///
	xtitle(Age) ytitle(Average marginal effect of log credit limit) ///
	title("") name(dyln_cclimit, replace) 
graph export "$OUTDIR/margins_lnlimit_ageEM.pdf", as(pdf) font(Times) replace 

matrix margins = at_debt[1...,"ccut"], at_debt[1...,"age"], b_debt[1...,1], b_limit[1...,1]
capture drop margins*
svmat margins, names(margins)
capture drop long_limit
gen long_limit = margins4/(1-margins3)
capture drop mar_age mar_ccuse
rename margins2 mar_age
rename margins1 mar_ccuse
twoway (connect long_limit mar_age if abs(mar_ccuse -.1)<.001, msymbol(circle)) ///
	(connect long_limit mar_age if abs(mar_ccuse -.4)<.001, msymbol(diamond)) ///
	(connect long_limit mar_age if abs(mar_ccuse -.7)<.001, msymbol(triangle)) ///
	(connect long_limit mar_age if abs(mar_ccuse -.8)<.001, msymbol(square)) ///
	(connect long_limit mar_age if abs(mar_ccuse -.9)<.001, msymbol(Oh)) ///
	(connect long_limit mar_age if abs(mar_ccuse -1)<.001, msymbol(Dh)) ///
	, legend(cols(4) order(- "Utilitzation" 1 2 3 - " " 4 5 6) ///
	label(1 "0.1") label(2 "0.4") label(3 "0.7") label(4 "0.8") label(5 "0.9") label(6 "1") ) ///
	xtitle(Age) ytitle(Long term impact of log credit limit) ///
	title("") name(long_dyln_cclimit, replace) 
graph export "$OUTDIR/margins_long_lnlimit_ageEM.pdf", as(pdf) font(Times) replace 



exit


