set scheme s1color, permanently

/******
Project: Credit cards Life-cycle
Date: July 3, 2019
Programer: Scott Fulford
Purpose: Load in SCPC and do life-cycle graphs
Update: also load MEM and do similar graphs for comparison
****/

/*** Directory structure **/
global CCPPANEL "/PanelData/"
global ROOTDIR "/Credit_cards/Revolver"
local INDIR "$ROOTDIR/Intermediate/"
local PROGDIR "$ROOTDIR/Programs/"
global OUTDIR "$ROOTDIR/Intermediate/"
global MEMDIR "MakingEndsMeet/Data"
global SCPCDIR "$ROOTDIR/Intermediate/SCPC"


/***Load MEM and CCP for MEM sample, process so looks like CCP panel */
use "$MEMDIR/Wave1/MakingEndsMeetWave1_final", clear

keep if disposition <.
gen date = monthly("jun2019", "MY")
tempfile mem
save `mem', replace

use "$MEMDIR/MEM_CCPvariables", clear


//Reshape with a generic list
*put all the needed future in a local macro
unab mylist: *_jun2019

*cut out the "_june2019" at the end to obtain the actual stubs
foreach v of local mylist {
	local stubs `"`stubs' `=substr("`v'",1,length("`v'")-8)'"' 
} 
disp "`stubs'"
*reshape (assuming you have a unique identifier "id")
reshape long `stubs', i(consumer_nb) j(date_stub) string
replace date_stub = substr(date_stub, 2, .)
gen date = monthly(date_stub, "MY")

merge 1:1 consumer_nb date using `mem'
drop date_stub _merge
gen inMEM=1

//Fill back when observe birth year, note that fills in again for panel
//Note: birth year not included before 2009. We do observe consumers who are only
//there before 2009. So using age necessarily drops these consumers.
replace birthyear = . if birthyear >=.
by consumer_nb: egen birthyear_filled = mean(birthyear)
gen year = year(dofm(date))
capture drop age
gen age = year - birthyear_filled
drop year

save `mem', replace


/*** Descriptives of revolving ***/
gen revolver = q39
egen agecat =cut(age), at(20,25(5)75, 120) icodes label
svy: mean revolver, over(agecat)
estimates store MEMagecat



gen ccuse = ccdebt/cclimit
replace ccuse = . if ccuse >3
egen ccusecat =cut(ccuse), at(0, .01,.1,.2(.1)1.1, 1.5) icodes label
svy: mean revolver, over(ccusecat)
coefplot, recast(connected) vertical ///
	rename( ///
	c.revolver@0.ccusecat=0- ///
	c.revolver@1.ccusecat=1- ///
	c.revolver@2.ccusecat=10- ///
	c.revolver@3.ccusecat=20- ///
	c.revolver@4.ccusecat=30- ///
	c.revolver@5.ccusecat=40- ///
	c.revolver@6.ccusecat=50- ///
	c.revolver@7.ccusecat=60- ///
	c.revolver@8.ccusecat=70- ///
	c.revolver@9.ccusecat=80- ///
	c.revolver@10.ccusecat=90- ///
	c.revolver@11.ccusecat=100- ///
	c.revolver@12.ccusecat=110- ///
	) xtitle(Credit card utilization percentage group) ytitle(Fraction revolving) ///
	name(Utilization_revolverMEM, replace)
graph export "$OUTDIR/Utilization_revolverMEM.pdf", as(pdf) font(Times) replace name(Utilization_revolverMEM)		

set more off
use "/home/work/users/fulfords/Research/Credit_cards/Revolver/Intermediate/SCPC/scpc_2012_stata.dta", clear 
gen year =2012
forvalues year == 2013/2017 {
	append using "$SCPCDIR/scpc_`year'_stata.dta" 
	replace year =`year' if year ==.
}

capture drop ccadopter //ccadopter only defined in later years
gen ccadopter =0
replace ccadopter =1 if pa053==1
replace ccadopter =1 if pa019_a == 1 | pa019_b == 1 | pa019_c == 1 | pa019_d == 1 | pa019_e == 1 | pa019_f == 1 | pa019_g == 1
sum ccadopter
gen revolver =0 if ccadopter==1
replace revolver =1 if pu010 >0 & pu010<. & ccadopter ==1

gen cc_user =0 
replace cc_user =1 if cc_sh >0 &cc_sh <. & ccadopter ==1

svyset prim_key [pw=r_weight]

egen agecat = cut(age), at(20,25(5)75 100) icodes label

///Form ccredit card adopter and share of payments graphs

//Overall

svy: mean cc_sh if ccadopter
svy: mean ccadopter
svy: mean cc_user 
svy: mean cc_user if ccadopter

svy: mean cc_sh if ccadopter, over(agecat)
estimates store SCPC_cc_share
svy: mean ccadopter, over(agecat)
estimates store SCPC_ccadopter


svy: mean cc_user , over(agecat)
estimates store SCPC_cc_user
exit
coefplot (SCPC_ccadopter, label(Credit card adopter) ///
	rename( ///
	c.ccadopter@0.agecat=20- ///
	c.ccadopter@1.agecat=25- ///
	c.ccadopter@2.agecat=30- ///
	c.ccadopter@3.agecat=35- ///
	c.ccadopter@4.agecat=40- ///
	c.ccadopter@5.agecat=45- ///
	c.ccadopter@6.agecat=50- ///
	c.ccadopter@7.agecat=55- ///
	c.ccadopter@8.agecat=60- ///
	c.ccadopter@9.agecat=65- ///
	c.ccadopter@10.agecat=70- ///
	c.ccadopter@11.agecat=75- ///
	)) ///
	(SCPC_cc_user, label(Credit card user) msymbol(T) ///
	///
	rename( ///
	c.cc_user@0.agecat=20- ///
	c.cc_user@1.agecat=25- ///
	c.cc_user@2.agecat=30- ///
	c.cc_user@3.agecat=35- ///
	c.cc_user@4.agecat=40- ///
	c.cc_user@5.agecat=45- ///
	c.cc_user@6.agecat=50- ///
	c.cc_user@7.agecat=55- ///
	c.cc_user@8.agecat=60- ///
	c.cc_user@9.agecat=65- ///
	c.cc_user@10.agecat=70- ///
	c.cc_user@11.agecat=75- ///
	)) ///
	(SCPC_cc_share, label(Share of payments using a credit card (if adopter)) msymbol(S) ///
	///
	rename( ///
	c.cc_sh@0.agecat=20- ///
	c.cc_sh@1.agecat=25- ///
	c.cc_sh@2.agecat=30- ///
	c.cc_sh@3.agecat=35- ///
	c.cc_sh@4.agecat=40- ///
	c.cc_sh@5.agecat=45- ///
	c.cc_sh@6.agecat=50- ///
	c.cc_sh@7.agecat=55- ///
	c.cc_sh@8.agecat=60- ///
	c.cc_sh@9.agecat=65- ///
	c.cc_sh@10.agecat=70- ///
	c.cc_sh@11.agecat=75- ///
	)), recast(connected) vertical ///
	legend(on rows(3)) xtitle(Age group) ytitle(Fraction) ///
	name(Life_cycle_adopterCPC, replace)
	
graph export "$OUTDIR/Life_cycle_adopterCPC.pdf", as(pdf) font(Times) replace name(Life_cycle_adopterCPC)		
exit

svy: mean revolver, over(agecat) 
estimates store SCPCagecat


coefplot (MEMagecat, label(Making Ends Meet)) ///
	(SCPCagecat, label(Survey of Consumer Payment Choice) msymbol(S)), recast(connected) vertical ///
	rename( ///
	c.revolver@0.agecat=20- ///
	c.revolver@1.agecat=25- ///
	c.revolver@2.agecat=30- ///
	c.revolver@3.agecat=35- ///
	c.revolver@4.agecat=40- ///
	c.revolver@5.agecat=45- ///
	c.revolver@6.agecat=50- ///
	c.revolver@7.agecat=55- ///
	c.revolver@8.agecat=60- ///
	c.revolver@9.agecat=65- ///
	c.revolver@10.agecat=70- ///
	c.revolver@11.agecat=75- ///
	) xtitle(Age group) ytitle(Fraction revolving) ///
	name(Life_cycle_revolverSCPC_MEM, replace)
	
graph export "$OUTDIR/Life_cycle_revolverSCPC_MEM.pdf", as(pdf) font(Times) replace name(Life_cycle_revolverSCPC_MEM)	
exit

  
